pub(super) fn rows_response(
rows: Vec<(Row, NonZeroI64)>,
order_by: &[ColumnOrder],
) -> PeekResponseExpand description
Builds the peek’s answer out of the rows a completed walk produced, sorted by order_by.
pub(super) fn rows_response(
rows: Vec<(Row, NonZeroI64)>,
order_by: &[ColumnOrder],
) -> PeekResponseBuilds the peek’s answer out of the rows a completed walk produced, sorted by order_by.